@@ -22,6 +22,7 @@
 from .deprecated import _custom_ioa_deprecated
 from .deprecated import _discover_deprecated
 from .deprecated import _firewall_management_deprecated
+from .deprecated import _hosts_deprecated
 from .deprecated import _identity_protection_deprecated
 from .deprecated import _installation_tokens_deprecated
 from .deprecated import _ioc_deprecated
@@ -133,6 +134,7 @@ deprecated_endpoints = []
 deprecated_endpoints.extend(_custom_ioa_deprecated)
 deprecated_endpoints.extend(_discover_deprecated)
 deprecated_endpoints.extend(_firewall_management_deprecated)
+deprecated_endpoints.extend(_hosts_deprecated)
 deprecated_endpoints.extend(_identity_protection_deprecated)
 deprecated_endpoints.extend(_installation_tokens_deprecated)
 deprecated_endpoints.extend(_ioc_deprecated)
