@@ -106,6 +106,42 @@ _d4c_registration_endpoints = [
       }
     ]
   ],
+  [
+    "DiscoverCloudAzureDownloadCertificate",
+    "GET",
+    "/cloud-connect-azure/entities/download-certificate/v1",
+    "Returns JSON object(s) that contain the base64 encoded certificate for a service principal.",
+    "d4c_registration",
+    [
+      {
+        "type": "array",
+        "items": {
+          "maxLength": 36,
+          "minLength": 36,
+          "pattern": "^[0-9a-z-]{36}$",
+          "type": "string"
+        },
+        "collectionFormat": "multi",
+        "description": "Azure Tenant ID",
+        "name": "tenant_id",
+        "in": "query",
+        "required": True
+      },
+      {
+        "maxLength": 5,
+        "minLength": 4,
+        "pattern": "^(true|false)$",
+        "enum": [
+          "false",
+          "true"
+        ],
+        "type": "string",
+        "default": False,
+        "name": "refresh",
+        "in": "query"
+      }
+    ]
+  ],
   [
     "GetCSPMAzureUserScriptsAttachment",
     "GET",
