@@ -36,7 +36,7 @@ OTHER DEALINGS IN THE SOFTWARE.
 For more information, please refer to <https://unlicense.org>
 """
 from ._util import force_default, process_service_request
-from ._payload import generic_payload_list
+from ._payload import generic_payload_list, incident_action_parameters
 from ._service_class import ServiceClass
 from ._endpoint._incidents import _incidents_endpoints as Endpoints
 
@@ -124,12 +124,36 @@ class Incidents(ServiceClass):
 
         Keyword arguments:
         action_parameters -- Action specific parameters. List of dictionaries.
+        add_tag -- Adds the associated value as a new tag on all the incidents of the ids list.
+                   Overridden if action_parameters is specified. Multiple values may be provided.
+                   String, comma delimited string, or list.
+        delete_tag -- Deletes tags matching the value from all the incidents in the ids list.
+                      Overridden if action_parameters is specified. Multiple values may be provided.
+                      String, comma delimited string or list.
+        unassign -- Unassigns all users from all of the incidents in the ids list.
+                    Overridden if action_parameters is specified. Boolean.
+        update_name -- Updates the name to the parameter value of all the incidents
+                       in the ids list. Overridden if action_parameters is specified. String.
+        update_assigned_to_v2 -- Assigns the user matching the UUID in the parameter
+                                 value to all of the incidents in the ids list. For information
+                                 on getting the UUID of a user, see Find existing users.
+                                 Overridden if action_parameters is specified. UUID string.
+        update_description -- Updates the description to the parameter value of all the
+                              incidents listed in the ids list.
+                              Overridden if action_parameters is specified. String.
+        update_status -- Updates the status to the parameter value of all the incidents
+                         in the ids list. Valid status values are 20, 25, 30, or 40:
+                            20: New
+                            25: Reopened
+                            30: In Progress
+                            40: Closed
+                         Overridden if action_parameters is specified. Integer string.
         body -- full body payload, not required if ids is provided as keyword.
                 {
                     "action_parameters": [
                         {
-                        "name": "string",
-                        "value": "string"
+                            "name": "string",
+                            "value": "string"
                         }
                     ],
                     "ids": [
@@ -138,7 +162,6 @@ class Incidents(ServiceClass):
                 }
         ids -- Incident ID(s) to perform actions against. String or list of strings.
 
-
         This method only supports keywords for providing arguments.
 
         Returns: dict object containing API response.
@@ -150,6 +173,10 @@ class Incidents(ServiceClass):
         """
         if not body:
             body = generic_payload_list(submitted_keywords=kwargs, payload_value="ids")
+            act_params = incident_action_parameters(passed_keywords=kwargs)
+            if act_params:
+                body["action_parameters"] = act_params
+            # Passing an action_parameters list will override provided individual keywords
             if kwargs.get("action_parameters", None):
                 body["action_parameters"] = kwargs.get("action_parameters", None)
 
